ElementCreator | django_cradmin API Document

    import ElementCreator from 'django_cradmin/scripts/django_cradmin/utilities/ElementCreator.js'

public class | source

# ElementCreator

## Constructor Summary

Public Constructor
public | constructor(tagName: *) |

## Method Summary

Public Methods
public | addAttribute(attribute: *, attributeValue: string) |
public | addCssClass(className: *) |
public | changeTagName(tagName: *) |
public | renderElement(): * |
public | reset(newTagName: *) |
public | setValue(value: *) |
public | useElement(element: *) |

## Public Constructors

### public constructor(tagName: *) source

#### Params:

Name | Type | Attribute | Description
tagName | * | optional default: null |

## Public Methods

### public addAttribute(attribute: *, attributeValue: string) source

#### Params:

Name | Type | Attribute | Description
attribute | * |  |
attributeValue | string | optional default: |

### public addCssClass(className: *) source

#### Params:

Name | Type | Attribute | Description
className | * |  |

### public changeTagName(tagName: *) source

#### Params:

Name | Type | Attribute | Description
tagName | * |  |

### public renderElement(): * source

#### Return:

*

### public reset(newTagName: *) source

#### Params:

Name | Type | Attribute | Description
newTagName | * | optional |

### public setValue(value: *) source

#### Params:

Name | Type | Attribute | Description
value | * |  |

### public useElement(element: *) source

#### Params:

Name | Type | Attribute | Description
element | * |  |